==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/zu/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Umsebenzisi ukhanse isicelo sezinto kuwebhusayithi',
    'a_user_requested' => 'Umsebenzisi ucele into ku-website',
    'accessory_name' => 'Igama lokufinyelela:',
    'additional_notes' => 'Amanothi angeziwe:',
    'admin_has_created' => 'Umlawuli udale i-akhawunti kuwe: iwebhusayithi yewebhu.',
    'asset' => 'Impahla:',
    'asset_name' => 'Igama lomhlaba:',
    'asset_requested' => 'Ifa liceliwe',
    'asset_tag' => 'Ithegi yetekisi:',
    'assigned_to' => 'Kwabiwa Ku',
    'best_regards' => 'Ozithobayo,',
    'canceled' => 'Ikhanseliwe:',
    'checkin_date' => 'Usuku lokuhlola:',
    'checkout_date' => 'Usuku lokuhlola:',
    'click_to_confirm' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuqinisekisa i-akhawunti yakho yewebhu:',
    'click_on_the_link_accessory' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole i-accessory.',
    'click_on_the_link_asset' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole ifa.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'I-QTY yamanje',
    'Days' => 'Izinsuku',
    'days' => 'Izinsuku',
    'expecting_checkin_date' => 'Ilanga le-Checkin elilindelekile:',
    'expires' => 'Iphelelwa yisikhathi',
    'Expiring_Assets_Report' => 'Ukubika Okubanjelwe Amafa.',
    'Expiring_Licenses_Report' => 'Umbiko Welayisense Okuphelelwa yisikhathi.',
    'hello' => 'Sawubona',
    'hi' => 'Sawubona',
    'i_have_read' => 'Ngifunde futhi ngiyavumelana nemigomo yokusetshenziswa, futhi ngithole le nto.',
    'item' => 'Into:',
    'Item_Request_Canceled' => 'Into yokucela ikhanseliwe',
    'Item_Requested' => 'Into ifunwe',
    'link_to_update_password' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuze ubuyekeze: iphasiwedi yakho yewebhu:',
    'login_first_admin' => 'Ngena ngemvume ekufakweni kwakho okusha kwe-Snipe-IT usebenzisa iziqinisekiso ezingezansi:',
    'login' => 'Ngena ngemvume:',
    'Low_Inventory_Report' => 'Umbiko Wokungenisa Okuphansi',
    'min_QTY' => 'I-Min QTY',
    'name' => 'Igama',
    'new_item_checked' => 'Into entsha ihloliwe ngaphansi kwegama lakho, imininingwane ingezansi.',
    'password' => 'Iphasiwedi:',
    'password_reset' => 'I-Password Setha kabusha',

    'read_the_terms' => 'Sicela ufunde imigomo yokusetshenziswa ngezansi.',
    'read_the_terms_and_click' => 'Sicela ufunde imigomo yokusetshenziswa ngezansi, bese uchofoza isixhumanisi phansi ukuze uqinisekise ukuthi ufunda futhi uvumelana nemigomo yokusetshenziswa, futhi uthole ifa.',
    'requested' => 'Ucele:',
    'reset_link' => 'Iphasiwedi yakho Hlaziya kabusha Isixhumanisi',
    'reset_password' => 'Chofoza lapha ukuze usethe kabusha iphasiwedi yakho:',
    'serial' => 'Serial',
    'supplier' => 'Umphakeli',
    'tag' => 'Maka',
    'test_email' => 'I-imeyili yokuhlola evela ku-Snipe-IT',
    'test_mail_text' => 'Lokhu kuhlolwa kusuka ohlelweni lwezokuphathwa kwe-Asset ye-Snipe-IT. Uma unalokhu, i-imeyili isebenza :)',
    'the_following_item' => 'Into elandelayo ihloliwe ku:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Ukuze usethe kabusha: iphasiwedi yewebhu, ugcwalise leli fomu:',
    'type' => 'Thayipha',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Siyakwamukela: igama',
    'welcome_to' => 'Siyakwamukela ku: iwebhu!',
    'your_credentials' => 'Izimpawu zakho ze-Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/zu/mail.php <==
<?php

return [
    'a_user_canceled' => 'Umsebenzisi ukhanse isicelo sezinto kuwebhusayithi',
    'a_user_requested' => 'Umsebenzisi ucele into ku-website',
    'accessory_name' => 'Igama lokufinyelela:',
    'additional_notes' => 'Amanothi angeziwe:',
    'admin_has_created' => 'Umlawuli udale i-akhawunti kuwe: iwebhusayithi yewebhu.',
    'asset' => 'Impahla:',
    'asset_name' => 'Igama lomhlaba:',
    'asset_requested' => 'Ifa liceliwe',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Kwabiwa Ku',
    'best_regards' => 'Ozithobayo,',
    'canceled' => 'Ikhanseliwe:',
    'checkin_date' => 'Usuku lokuhlola:',
    'checkout_date' => 'Usuku lokuhlola:',
    'click_to_confirm' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuqinisekisa i-akhawunti yakho yewebhu:',
    'click_on_the_link_accessory' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole i-accessory.',
    'click_on_the_link_asset' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole ifa.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'I-QTY yamanje',
    'Days' => 'Izinsuku',
    'days' => 'Izinsuku',
    'expecting_checkin_date' => 'Ilanga le-Checkin elilindelekile:',
    'expires' => 'Iphelelwa yisikhathi',
    'Expiring_Assets_Report' => 'Ukubika Okubanjelwe Amafa.',
    'Expiring_Licenses_Report' => 'Umbiko Welayisense Okuphelelwa yisikhathi.',
    'hello' => 'Sawubona',
    'hi' => 'Sawubona',
    'i_have_read' => 'Ngifunde futhi ngiyavumelana nemigomo yokusetshenziswa, futhi ngithole le nto.',
    'item' => 'Into:',
    'Item_Request_Canceled' => 'Into yokucela ikhanseliwe',
    'Item_Requested' => 'Into ifunwe',
    'link_to_update_password' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuze ubuyekeze: iphasiwedi yakho yewebhu:',
    'login_first_admin' => 'Ngena ngemvume ekufakweni kwakho okusha kwe-Snipe-IT usebenzisa iziqinisekiso ezingezansi:',
    'login' => 'Ngena ngemvume:',
    'Low_Inventory_Report' => 'Umbiko Wokungenisa Okuphansi',
    'min_QTY' => 'I-Min QTY',
    'name' => 'Igama',
    'new_item_checked' => 'Into entsha ihloliwe ngaphansi kwegama lakho, imininingwane ingezansi.',
    'password' => 'Iphasiwedi:',
    'password_reset' => 'I-Password Setha kabusha',

    'read_the_terms' => 'Sicela ufunde imigomo yokusetshenziswa ngezansi.',
    'read_the_terms_and_click' => 'Sicela ufunde imigomo yokusetshenziswa ngezansi, bese uchofoza isixhumanisi phansi ukuze uqinisekise ukuthi ufunda futhi uvumelana nemigomo yokusetshenziswa, futhi uthole ifa.',
    'requested' => 'Ucele:',
    'reset_link' => 'Iphasiwedi yakho Hlaziya kabusha Isixhumanisi',
    'reset_password' => 'Chofoza lapha ukuze usethe kabusha iphasiwedi yakho:',
    'serial' => 'Serial',
    'supplier' => 'Umphakeli',
    'tag' => 'Maka',
    'test_email' => 'I-imeyili yokuhlola evela ku-Snipe-IT',
    'test_mail_text' => 'Lokhu kuhlolwa kusuka ohlelweni lwezokuphathwa kwe-Asset ye-Snipe-IT. Uma unalokhu, i-imeyili isebenza :)',
    'the_following_item' => 'Into elandelayo ihloliwe ku:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Ukuze usethe kabusha: iphasiwedi yewebhu, ugcwalise leli fomu:',
    'type' => 'Thayipha',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Siyakwamukela: igama',
    'welcome_to' => 'Siyakwamukela ku: iwebhu!',
    'your_credentials' => 'Izimpawu zakho ze-Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
